@@ -154,7 +154,7 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
         auto t = myEngine.globalObject();
         t.setProperty(QStringLiteral("skgresult"), myEngine.newQObject(ui.kSQLResult));
         t.setProperty(QStringLiteral("skgdocument"), myEngine.newQObject(getDocument()));
-        t.setProperty(QStringLiteral("skgerror"), myEngine.newQObject(&err));
+        // t.setProperty(QStringLiteral("skgerror"), myEngine.newQObject(&err));
         t.setProperty(QStringLiteral("skgmainpanel"), myEngine.newQObject(SKGMainPanel::getMainPanel()));
 
         // Finally execute the scripting code.
