@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
+ *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
  * A plugin to highlight objects
@@ -39,19 +39,19 @@ K_PLUGIN_FACTORY(SKGHighlightPluginFactory, registerPlugin<SKGHighlightPlugin>()
 SKGHighlightPlugin::SKGHighlightPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
 {
-    Q_UNUSED(iWidget);
-    SKGTRACEINFUNC(10);
+    Q_UNUSED(iWidget)
+    SKGTRACEINFUNC(10)
 }
 
 SKGHighlightPlugin::~SKGHighlightPlugin()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     m_currentDocument = nullptr;
 }
 
 bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument)
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
 
     m_currentDocument = iDocument;
 
@@ -96,20 +96,20 @@ int SKGHighlightPlugin::getOrder() const
 void SKGHighlightPlugin::onSwitchClose()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
     // Get Selection
     if ((SKGMainPanel::getMainPanel() != nullptr) && (m_currentDocument != nullptr)) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
         {
-            SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Close"), err, nb);
+            SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Close"), err, nb)
             for (int i = 0; !err && i < nb; ++i) {
                 SKGObjectBase obj(selection.at(i));
                 IFOKDO(err, obj.setAttribute(QStringLiteral("t_close"), obj.getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y") ? QStringLiteral("N") : QStringLiteral("Y")))
                 IFOKDO(err, obj.save())
 
                 // Send message
-                IFOKDO(err, m_currentDocument->sendMessage(i18nc("An information to the user", "The close status of '%1' has been changed", obj.getDisplayName()), SKGDocument::Hidden));
+                IFOKDO(err, m_currentDocument->sendMessage(i18nc("An information to the user", "The close status of '%1' has been changed", obj.getDisplayName()), SKGDocument::Hidden))
 
                 IFOKDO(err, m_currentDocument->stepForward(i + 1))
             }
@@ -129,20 +129,20 @@ void SKGHighlightPlugin::onSwitchClose()
 void SKGHighlightPlugin::onSwitchHighLight()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
     // Get Selection
     if ((SKGMainPanel::getMainPanel() != nullptr) && (m_currentDocument != nullptr)) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
         {
-            SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Highlight"), err, nb);
+            SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Highlight"), err, nb)
             for (int i = 0; !err && i < nb; ++i) {
                 SKGObjectBase obj(selection.at(i));
                 IFOKDO(err, obj.setAttribute(QStringLiteral("t_bookmarked"), obj.getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y") ? QStringLiteral("N") : QStringLiteral("Y")))
                 IFOKDO(err, obj.save())
 
                 // Send message
-                IFOKDO(err, m_currentDocument->sendMessage(i18nc("An information to the user", "The highlight status of '%1' has been changed", obj.getDisplayName()), SKGDocument::Hidden));
+                IFOKDO(err, m_currentDocument->sendMessage(i18nc("An information to the user", "The highlight status of '%1' has been changed", obj.getDisplayName()), SKGDocument::Hidden))
 
                 IFOKDO(err, m_currentDocument->stepForward(i + 1))
             }
