@@ -52,7 +52,7 @@ SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* iWidget, QObject* iParent, con
     m_billsProcess.start(QStringLiteral("boobill bills  -q -f csv -v"));
 
     connect(&m_billsProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &SKGPropertiesPlugin::onBillsRetreived);
-    connect(&m_billsProcess, static_cast<void (QProcess::*)(QProcess::ProcessError)>(&QProcess::error), this, &SKGPropertiesPlugin::onBillsRetreived);
+    connect(&m_billsProcess, static_cast<void (QProcess::*)(QProcess::ProcessError)>(&QProcess::errorOccurred), this, &SKGPropertiesPlugin::onBillsRetreived);
 }
 
 SKGPropertiesPlugin::~SKGPropertiesPlugin()
@@ -66,6 +66,10 @@ SKGPropertiesPlugin::~SKGPropertiesPlugin()
     if (m_billsProcess.state() == QProcess::Running) {
         m_billsProcess.kill();
     }
+    if (m_billsProcess.state() == QProcess::Running) {
+        m_billsProcess.kill();
+        m_billsProcess.waitForFinished(-1);
+    }
 }
 
 void SKGPropertiesPlugin::onBillsRetreived()
