@@ -12,11 +12,10 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
+ *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin for PDF import / export.
- * http://jerome.girod.perso.sfr.fr/finance/pdfx.php
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -43,8 +42,8 @@ K_PLUGIN_FACTORY(SKGImportPluginPDFFactory, registerPlugin<SKGImportPluginPDF>()
 SKGImportPluginPDF::SKGImportPluginPDF(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEINFUNC(10);
-    Q_UNUSED(iArg);
+    SKGTRACEINFUNC(10)
+    Q_UNUSED(iArg)
 }
 
 SKGImportPluginPDF::~SKGImportPluginPDF()
@@ -52,7 +51,7 @@ SKGImportPluginPDF::~SKGImportPluginPDF()
 
 bool SKGImportPluginPDF::isImportPossible()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("PDF"));
 }
 
@@ -114,7 +113,7 @@ SKGError SKGImportPluginPDF::importFile()
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
-    SKGTRACEINFUNCRC(2, err);
+    SKGTRACEINFUNCRC(2, err)
 
     // Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "PDF"), 2);
@@ -207,13 +206,13 @@ SKGError SKGImportPluginPDF::importFile()
 
                                     // Create operation
                                     SKGOperationObject operation;
-                                    IFOKDO(err, account.addOperation(operation, true));
+                                    IFOKDO(err, account.addOperation(operation, true))
                                     IFOKDO(err, operation.setDate(d))
 
 
                                     IFOKDO(err, operation.setUnit(unit))
                                     SKGPayeeObject payeeObj;
-                                    IFOKDO(err, SKGPayeeObject::createPayee(m_importer->getDocument(), payee, payeeObj));
+                                    IFOKDO(err, SKGPayeeObject::createPayee(m_importer->getDocument(), payee, payeeObj))
                                     IFOKDO(err, operation.setPayee(payeeObj))
                                     IFOKDO(err, operation.setComment(comment))
                                     IFOKDO(err, operation.setMode(mode))
@@ -225,7 +224,7 @@ SKGError SKGImportPluginPDF::importFile()
                                     SKGSubOperationObject subop;
                                     IFOKDO(err, operation.addSubOperation(subop))
                                     IFOKDO(err, subop.setComment(comment))
-                                    IFOKDO(err, subop.setQuantity(-amount));
+                                    IFOKDO(err, subop.setQuantity(-amount))
                                     IFOKDO(err, subop.save(false, false))
 
                                     // Add file
@@ -247,7 +246,7 @@ SKGError SKGImportPluginPDF::importFile()
             }
         }
     }
-    SKGENDTRANSACTION(m_importer->getDocument(),  err);
+    SKGENDTRANSACTION(m_importer->getDocument(),  err)
 
     return err;
 }
