@@ -331,6 +331,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                         html += QStringLiteral("<html><head><style>a {color: #") + color + ";}</style></head><body><table>";
                         double sumTypeV1 = 0;
                         double sumV1 = 0;
+                        int nbAdded = 0;
                         QString currentType;
                         int nb = listTmp.count();
                         for (int i = 1; i < nb; ++i) {  // Ignore header
@@ -342,10 +343,11 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                             bool closed = (r.at(4) == QStringLiteral("Y"));
 
                             if (type != currentType) {
-                                if (!currentType.isEmpty()) {
+                                if (!currentType.isEmpty() && nbAdded > 0) {
                                     html += "<tr><td><b>" % SKGServices::stringToHtml(i18nc("the numerical total of a sum of values", "Total of %1", currentType)) % "</b></td>"
                                             "<td align=\"right\"><b>" % doc->formatMoney(sumTypeV1, primary) % "</b></td></tr>";
                                     sumTypeV1 = 0;
+                                    nbAdded = 0;
                                 }
                                 currentType = type;
                             }
@@ -367,6 +369,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                 }
                                 html += doc->formatMoney(v1, primary);
                                 html += QStringLiteral("</td></tr>");
+                                ++nbAdded;
                             }
                             sumTypeV1 += v1;
                             sumV1 += v1;
