@@ -196,9 +196,15 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
     connect(ui.kUpBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onUp);
     connect(ui.kDownBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onDown);
     connect(ui.kBottomBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onBottom);
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     connect(ui.kYearAuto, static_cast<void (QSpinBox::*)(const QString&)>(&QSpinBox::valueChanged), this, [ = ](const QString & text) {
         ui.kRemovePrevious->setText(i18nc("Option", "Remove existing budgets for %1", text));
     });
+#else
+    connect(ui.kYearAuto, &QSpinBox::textChanged, this, [ = ](const QString & text) {
+        ui.kRemovePrevious->setText(i18nc("Option", "Remove existing budgets for %1", text));
+    });
+#endif
     ui.kYearAuto->setValue(QDate::currentDate().year());
 
     ui.kWidgetSelector->setSelectedMode(0);
