@@ -620,7 +620,7 @@ void SKGImportExportPlugin::importFiles(const QList<QUrl>& iFiles, int mode, boo
             m_install = false;
             KMessageWidget* msg = SKGMainPanel::displayErrorMessage(err);
             if (err.getReturnCode() == ERR_INSTALL && (msg != nullptr)) {
-                QString application = err.property("application").toString();
+                QString application = err.getProperty();
                 auto install = new QAction(i18nc("Noun", "Install %1", application), msg);
                 install->setIcon(SKGServices::fromTheme(QStringLiteral("download")));
                 msg->addAction(install);
