@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
+ *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin for operation management.
@@ -41,7 +41,7 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(QWidget* iParent, SKGDocument*
     : SKGBoardWidget(iParent, iDocument, i18nc("Dashboard widget title", "Income & Expenditure")),
       m_periodEdit1(nullptr), m_periodEdit2(nullptr), m_anim(nullptr)
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
 
     m_timer.setSingleShot(true);
     connect(&m_timer, &QTimer::timeout, this, [ = ]() {
@@ -169,7 +169,7 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(QWidget* iParent, SKGDocument*
 
 SKGOperationBoardWidget::~SKGOperationBoardWidget()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     m_menuGroup = nullptr;
     m_menuTransfer = nullptr;
     m_menuTracked = nullptr;
@@ -270,8 +270,8 @@ void SKGOperationBoardWidget::refreshDelayed()
 
 void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEINFUNC(10);
-    Q_UNUSED(iIdTransaction);
+    SKGTRACEINFUNC(10)
+    Q_UNUSED(iIdTransaction)
     QString table = ((m_menuSuboperation != nullptr) && m_menuSuboperation->isChecked() ? QStringLiteral("v_suboperation_consolidated") : QStringLiteral("v_operation_display"));
     if ((m_periodEdit1 != nullptr) && (m_periodEdit2 != nullptr) && (iTableName == table || iTableName.isEmpty())) {
         // Set titles
