@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
+ *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
  * A skrooge plugin to track operations.
@@ -37,7 +37,7 @@
 SKGPayeePluginWidget::SKGPayeePluginWidget(QWidget* iParent, SKGDocument* iDocument)
     : SKGTabPage(iParent, iDocument)
 {
-    SKGTRACEINFUNC(1);
+    SKGTRACEINFUNC(1)
     if (iDocument == nullptr) {
         return;
     }
@@ -85,7 +85,7 @@ SKGPayeePluginWidget::SKGPayeePluginWidget(QWidget* iParent, SKGDocument* iDocum
 
 SKGPayeePluginWidget::~SKGPayeePluginWidget()
 {
-    SKGTRACEINFUNC(1);
+    SKGTRACEINFUNC(1)
 }
 
 bool SKGPayeePluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -106,7 +106,7 @@ bool SKGPayeePluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 void SKGPayeePluginWidget::onSelectionChanged()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
 
     int nbSelect = ui.kView->getView()->getNbSelectedObjects();
     if (nbSelect == 1) {
@@ -127,7 +127,7 @@ void SKGPayeePluginWidget::onSelectionChanged()
 
 QString SKGPayeePluginWidget::getState()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     QDomDocument doc(QStringLiteral("SKGML"));
     QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
@@ -137,7 +137,7 @@ QString SKGPayeePluginWidget::getState()
 
 void SKGPayeePluginWidget::setState(const QString& iState)
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -158,7 +158,7 @@ QWidget* SKGPayeePluginWidget::mainWidget()
 
 void SKGPayeePluginWidget::onEditorModified()
 {
-    _SKGTRACEINFUNC(10);
+    _SKGTRACEINFUNC(10)
     int nb = getNbSelectedObjects();
     ui.kModifyButton->setEnabled(!ui.kNameInput->text().isEmpty() && nb >= 1);
     ui.kAddButton->setEnabled(!ui.kNameInput->text().isEmpty() &&
@@ -167,8 +167,8 @@ void SKGPayeePluginWidget::onEditorModified()
 
 void SKGPayeePluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
-    SKGTRACEINFUNC(10);
-    Q_UNUSED(iIdTransaction);
+    SKGTRACEINFUNC(10)
+    Q_UNUSED(iIdTransaction)
 
     if (!iLightTransaction) {
         if (iTableName == QStringLiteral("payee") || iTableName.isEmpty()) {
@@ -183,12 +183,12 @@ void SKGPayeePluginWidget::dataModified(const QString& iTableName, int iIdTransa
 void SKGPayeePluginWidget::onAddPayee()
 {
     SKGError err;
-    _SKGTRACEINFUNCRC(10, err);
+    _SKGTRACEINFUNCRC(10, err)
 
     QString name = ui.kNameInput->text();
     SKGPayeeObject payee;
     {
-        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Payee creation '%1'", name), err);
+        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Payee creation '%1'", name), err)
 
         IFOKDO(err, SKGPayeeObject::createPayee(qobject_cast<SKGDocumentBank*>(getDocument()), name, payee))
         IFOKDO(err, payee.setAddress(ui.kAddressEdit->text()))
@@ -202,7 +202,7 @@ void SKGPayeePluginWidget::onAddPayee()
         IFOKDO(err, payee.save())
 
         // Send message
-        IFOKDO(err, payee.getDocument()->sendMessage(i18nc("An information message", "The payee '%1' has been added", payee.getDisplayName()), SKGDocument::Hidden));
+        IFOKDO(err, payee.getDocument()->sendMessage(i18nc("An information message", "The payee '%1' has been added", payee.getDisplayName()), SKGDocument::Hidden))
     }
     // status bar
     IFOK(err) {
@@ -219,7 +219,7 @@ void SKGPayeePluginWidget::onAddPayee()
 void SKGPayeePluginWidget::onModifyPayee()
 {
     SKGError err;
-    _SKGTRACEINFUNCRC(10, err);
+    _SKGTRACEINFUNCRC(10, err)
 
     // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
@@ -227,7 +227,7 @@ void SKGPayeePluginWidget::onModifyPayee()
     int nb = selection.count();
 
     {
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Payee update"), err, nb);
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Payee update"), err, nb)
         auto name = ui.kNameInput->text();
         if (name != NOUPDATE && !name.startsWith(QLatin1String("="))) {
             // Is this name already existing?
@@ -257,7 +257,7 @@ void SKGPayeePluginWidget::onModifyPayee()
                     SKGPayeeObject payeeObj(selection.at(i));
 
                     // Send message
-                    IFOKDO(err, payeeObj.getDocument()->sendMessage(i18nc("An information message", "The payee '%1' has been merged with payee '%2'", payeeObj1.getDisplayName(), payeeObj.getDisplayName()), SKGDocument::Hidden));
+                    IFOKDO(err, payeeObj.getDocument()->sendMessage(i18nc("An information message", "The payee '%1' has been merged with payee '%2'", payeeObj1.getDisplayName(), payeeObj.getDisplayName()), SKGDocument::Hidden))
 
                     err = payeeObj1.merge(payeeObj);
                 }
@@ -286,7 +286,7 @@ void SKGPayeePluginWidget::onModifyPayee()
             IFOKDO(err, payee.save())
 
             // Send message
-            IFOKDO(err, payee.getDocument()->sendMessage(i18nc("An information message", "The payee '%1' has been updated", payee.getDisplayName()), SKGDocument::Hidden));
+            IFOKDO(err, payee.getDocument()->sendMessage(i18nc("An information message", "The payee '%1' has been updated", payee.getDisplayName()), SKGDocument::Hidden))
         }
     }
 
