@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
+ *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin to generate report.
@@ -43,7 +43,7 @@ static const int FORECASTMAX = 100;
 SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank* iDocument, bool iMinimmumMode)
     : SKGTabPage(iParent, iDocument), m_openReportAction(nullptr), m_openAction(nullptr), m_mode(0), m_nbLevelLines(0), m_nbLevelColumns(0), m_refreshNeeded(true)
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     if (iDocument == nullptr) {
         return;
     }
@@ -154,14 +154,47 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
                    QStringLiteral("t_REALREFUND") <<
                    QStringLiteral("t_TRANSFER");
 
-    // Adding properties
+    // Adding properties of operations and sub operations
     QStringList properties;
-    iDocument->getDistinctValues(QStringLiteral("parameters"), QStringLiteral("t_name"), QStringLiteral("(t_uuid_parent like '%-operation' OR t_uuid_parent like '%-suboperation')  AND t_name NOT LIKE 'SKG_%'"), properties);
+    iDocument->getDistinctValues(QStringLiteral("parameters"), QStringLiteral("'p_'||t_name"), QStringLiteral("(t_uuid_parent like '%-operation' OR t_uuid_parent like '%-suboperation')  AND t_name NOT LIKE 'SKG_%'"), properties);
     int nb = properties.count();
     m_attsForLines.reserve(m_attsForLines.count() + nb);
     for (int i = 0; i < nb; ++i) {
-        m_attsForLines.push_back("p_" % properties.at(i));
+        m_attsForLines.push_back(properties.at(i));
     }
+
+    // Adding properties of categories
+    iDocument->getDistinctValues(QStringLiteral("parameters"), '\'' + iDocument->getDisplay(QStringLiteral("t_category")) + ".p_'||t_name", QStringLiteral("t_uuid_parent like '%-category' AND t_name NOT LIKE 'SKG_%'"), properties);
+    nb = properties.count();
+    m_attsForLines.reserve(m_attsForLines.count() + nb);
+    for (int i = 0; i < nb; ++i) {
+        m_attsForLines.push_back(properties.at(i));
+    }
+
+    // Adding properties of accounts
+    iDocument->getDistinctValues(QStringLiteral("parameters"), '\'' + iDocument->getDisplay(QStringLiteral("t_account")) + ".p_'||t_name", QStringLiteral("t_uuid_parent like '%-account' AND t_name NOT LIKE 'SKG_%'"), properties);
+    nb = properties.count();
+    m_attsForLines.reserve(m_attsForLines.count() + nb);
+    for (int i = 0; i < nb; ++i) {
+        m_attsForLines.push_back(properties.at(i));
+    }
+
+    // Adding properties of payee
+    iDocument->getDistinctValues(QStringLiteral("parameters"), '\'' + iDocument->getDisplay(QStringLiteral("t_payee")) + ".p_'||t_name", QStringLiteral("t_uuid_parent like '%-payee' AND t_name NOT LIKE 'SKG_%'"), properties);
+    nb = properties.count();
+    m_attsForLines.reserve(m_attsForLines.count() + nb);
+    for (int i = 0; i < nb; ++i) {
+        m_attsForLines.push_back(properties.at(i));
+    }
+
+    // Adding properties of unit
+    iDocument->getDistinctValues(QStringLiteral("parameters"), '\'' + iDocument->getDisplay(QStringLiteral("t_unit")) + ".p_'||t_name", QStringLiteral("t_uuid_parent like '%-unit' AND t_name NOT LIKE 'SKG_%'"), properties);
+    nb = properties.count();
+    m_attsForLines.reserve(m_attsForLines.count() + nb);
+    for (int i = 0; i < nb; ++i) {
+        m_attsForLines.push_back(properties.at(i));
+    }
+
     if (!iMinimmumMode) {
         m_attsForColumns += m_attsForLines;
     }
@@ -181,18 +214,18 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
     // Refresh
     connect(ui.kPeriod, &SKGPeriodEdit::changed, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
 
-    connect(ui.kColumns, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentIndexChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
-    connect(ui.kLines, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentIndexChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
-    connect(ui.kMode, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentIndexChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kColumns, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kLines, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kMode, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
     connect(ui.kIncomes, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
     connect(ui.kExpenses, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
     connect(ui.kTransfers, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
     connect(ui.kGrouped, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
     connect(ui.kTracked, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
-    connect(ui.kForecastCmb, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentIndexChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kForecastCmb, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
     connect(ui.kForecastValue, static_cast<void (QSlider::*)(int)>(&QSlider::valueChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
     connect(ui.kCorrectedBy, static_cast<void (SKGUnitComboBox::*)(int)>(&SKGUnitComboBox::currentIndexChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
-    connect(ui.kCorrectedByMode, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentIndexChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kCorrectedByMode, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
 
     connect(getDocument(), &SKGDocument::tableModified, this, &SKGReportPluginWidget::dataModified);
     connect(SKGMainPanel::getMainPanel(), &SKGMainPanel::currentPageChanged, this, &SKGReportPluginWidget::pageChanged, Qt::QueuedConnection);
@@ -220,14 +253,14 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
 
 SKGReportPluginWidget::~SKGReportPluginWidget()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     m_openAction = nullptr;
     m_openReportAction = nullptr;
 }
 
 QString SKGReportPluginWidget::getState()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     QDomDocument doc(QStringLiteral("SKGML"));
     QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
@@ -292,7 +325,7 @@ QString SKGReportPluginWidget::getState()
 
 void SKGReportPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     m_timer.stop();
 
     QDomDocument doc(QStringLiteral("SKGML"));
@@ -503,7 +536,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, Q
         if (att == QStringLiteral("#NOTHING#")) {
             att = QLatin1String("");
         }
-        if (att.startsWith(QLatin1String("p_"))) {
+        if (att.startsWith(QLatin1String("p_")) || att.contains(QStringLiteral(".p_"))) {
             att = getWhereClauseForProperty(att);
         }
         if (att.isEmpty()) {
@@ -545,7 +578,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, Q
     if (att == QStringLiteral("#NOTHING#")) {
         att = QLatin1String("");
     }
-    if (att.startsWith(QLatin1String("p_"))) {
+    if (att.startsWith(QLatin1String("p_")) || att.contains(QStringLiteral(".p_"))) {
         att = getWhereClauseForProperty(att);
     }
     if (!att.isEmpty()) {
@@ -637,7 +670,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(QString& oWc, QSt
 
 void SKGReportPluginWidget::onDoubleClick(int row, int column)
 {
-    _SKGTRACEINFUNC(10);
+    _SKGTRACEINFUNC(10)
 
     QString wc;
     QString title;
@@ -661,7 +694,7 @@ void SKGReportPluginWidget::onOpen()
 void SKGReportPluginWidget::onOpenReport()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
     QString wc;
     QString title;
     getWhereClauseAndTitleForSelection(wc, title);
@@ -683,7 +716,7 @@ void SKGReportPluginWidget::onOpenReport()
 
 void SKGReportPluginWidget::onOneLevelMore()
 {
-    _SKGTRACEINFUNC(10);
+    _SKGTRACEINFUNC(10)
     if (sender() == ui.kLineUp) {
         ++m_nbLevelLines;
     } else {
@@ -694,7 +727,7 @@ void SKGReportPluginWidget::onOneLevelMore()
 
 void SKGReportPluginWidget::onOneLevelLess()
 {
-    _SKGTRACEINFUNC(10);
+    _SKGTRACEINFUNC(10)
     if (sender() == ui.kLineDown) {
         --m_nbLevelLines;
     } else {
@@ -705,7 +738,7 @@ void SKGReportPluginWidget::onOneLevelLess()
 
 void SKGReportPluginWidget::onAddLine()
 {
-    _SKGTRACEINFUNC(10);
+    _SKGTRACEINFUNC(10)
     m_attsForLinesAdded.push_back(m_attsForLines.value(ui.kLines->currentIndex()));
     ui.kLines->setCurrentIndex(0);
     refresh();
@@ -713,7 +746,7 @@ void SKGReportPluginWidget::onAddLine()
 
 void SKGReportPluginWidget::onRemoveLine()
 {
-    _SKGTRACEINFUNC(10);
+    _SKGTRACEINFUNC(10)
     if (!m_attsForLinesAdded.isEmpty()) {
         m_attsForLinesAdded.pop_back();
     }
@@ -886,8 +919,8 @@ void SKGReportPluginWidget::pageChanged()
 void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 
 {
-    SKGTRACEINFUNC(10);
-    Q_UNUSED(iIdTransaction);
+    SKGTRACEINFUNC(10)
+    Q_UNUSED(iIdTransaction)
 
     // Refresh panel
     QSqlDatabase* db = getDocument()->getMainDatabase();
@@ -1035,7 +1068,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 if (attCol == QStringLiteral("#NOTHING#")) {
                     attCol = QLatin1String("");
                 }
-                if (attCol.startsWith(QLatin1String("p_"))) {
+                if (attCol.startsWith(QLatin1String("p_")) || attCol.contains(QStringLiteral(".p_"))) {
                     attCol = getWhereClauseForProperty(attCol);
                 }
 
@@ -1050,7 +1083,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     if (att == QStringLiteral("#NOTHING#")) {
                         att = QLatin1String("");
                     }
-                    if (att.startsWith(QLatin1String("p_"))) {
+                    if (att.startsWith(QLatin1String("p_")) || att.contains(QStringLiteral(".p_"))) {
                         att = getWhereClauseForProperty(att);
                     }
                     if (att.isEmpty()) {
@@ -1411,6 +1444,25 @@ void SKGReportPluginWidget::setSettings()
 QString SKGReportPluginWidget::getWhereClauseForProperty(const QString& iProperty) const
 {
     QString propertyName = iProperty.right(iProperty.length() - 2);
+    QString check = getDocument()->getDisplay(QStringLiteral("t_category"));
+    if (iProperty.startsWith(check)) {
+        propertyName = iProperty.right(iProperty.length() - check.length() - 1 - 2);
+        return "(SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.i_IDCATEGORY||'-category' AND t_name='" % propertyName % "')";
+    }
+    check = getDocument()->getDisplay(QStringLiteral("t_account"));
+    if (iProperty.startsWith(check)) {
+        propertyName = iProperty.right(iProperty.length() - check.length() - 1 - 2);
+        return "(SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.rd_account_id||'-account' AND t_name='" % propertyName % "')";
+    }
+    check = getDocument()->getDisplay(QStringLiteral("t_payee"));
+    if (iProperty.startsWith(check)) {
+        propertyName = iProperty.right(iProperty.length() - check.length() - 1 - 2);
+        return "(SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.r_payee_id||'-payee' AND t_name='" % propertyName % "')";
+    }
+    check = getDocument()->getDisplay(QStringLiteral("t_unit"));
+    if (iProperty.startsWith(check)) {
+        propertyName = iProperty.right(iProperty.length() - check.length() - 1 - 2);
+        return "(SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.rc_unit_id||'-unit' AND t_name='" % propertyName % "')";
+    }
     return "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-suboperation' AND t_name='" % propertyName % "'), IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.i_OPID||'-operation' AND t_name='" % propertyName % "'), '#NULL#'))";
 }
-
