@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
+ *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin for bank management.
@@ -37,7 +37,7 @@
 SKGAlarmBoardWidget::SKGAlarmBoardWidget(QWidget* iParent, SKGDocument* iDocument)
     : SKGBoardWidget(iParent, iDocument, i18nc("Dashboard widget title", "Alarms"))
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
 
     // Create widget
     m_frame = new QFrame();
@@ -70,7 +70,7 @@ SKGAlarmBoardWidget::SKGAlarmBoardWidget(QWidget* iParent, SKGDocument* iDocumen
 
 SKGAlarmBoardWidget::~SKGAlarmBoardWidget()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
 
     m_menuFavorite = nullptr;
 }
@@ -102,8 +102,8 @@ void SKGAlarmBoardWidget::setState(const QString& iState)
 
 void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEINFUNC(10);
-    Q_UNUSED(iIdTransaction);
+    SKGTRACEINFUNC(10)
+    Q_UNUSED(iIdTransaction)
 
     if (iTableName == QStringLiteral("operation") || iTableName == QStringLiteral("rule") || iTableName.isEmpty()) {
         // Remove all item of the layout
