@@ -24,6 +24,7 @@
 #include <kaboutdata.h>
 #include <kactioncollection.h>
 #include <kpluginfactory.h>
+#include <kservicetypetrader.h>
 
 #include <qaction.h>
 #include <qinputdialog.h>
@@ -186,7 +187,43 @@ QWidget* SKGUnitPlugin::getPreferenceWidget()
     SKGTRACEINFUNC(10)
     auto w = new QWidget();
     ui.setupUi(w);
+
+    // Get sources from.desktop file
+    QStringList sources;
+    const auto list2 = KServiceTypeTrader::self()->query(QStringLiteral("skrooge/source"));
+    for (const auto& service : list2) {
+        auto name = service->property(QStringLiteral("X-KDE-PluginInfo-Name"), QVariant::String).toString();
+        auto keyAPI = service->property(QStringLiteral("X-SKROOGE-keyAPI"), QVariant::Bool).toBool();
+        if (!sources.contains(name) && keyAPI) {
+            sources.push_back(name);
+        }
+    }
+    sources.sort();
+
+    auto nb = sources.count();
+    auto lwidgets = new QHash<QString, QLineEdit*>();
+    for (auto i = 0; i < nb; ++i) {
+        // Get Current value
+        auto ln = new QLineEdit(w);
+        ln->setText(m_currentBankDocument->getParameter("KEYAPI_" + sources[i]));
+        lwidgets->insert(sources.value(i), ln);
+
+        ui.kAPIKeyLayout->addWidget(new QLabel(sources[i] + ':', w), i, 0);
+        ui.kAPIKeyLayout->addWidget(ln, i, 1);
+    }
+
     connect(ui.kcfg_download_on_open, &QCheckBox::toggled, ui.kcfg_download_frequency, &KComboBox::setEnabled);
+    connect(ui.kSave, &QPushButton::clicked, this, [ = ]() {
+        SKGError err;
+        {
+            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Save API keys"), err)
+            foreach (auto k,  lwidgets->keys()) {
+                m_currentBankDocument->setParameter("KEYAPI_" + k, lwidgets->value(k)->text());
+            }
+        }
+        // Display error
+        SKGMainPanel::displayErrorMessage(err);
+    });
 
     return w;
 }
