@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
+ *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin for unit management.
@@ -46,7 +46,7 @@
 SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDocument)
     : SKGTabPage(iParent, iDocument), m_upload(nullptr), m_unitValueGraphCmb(nullptr)
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     if (iDocument == nullptr) {
         return;
     }
@@ -272,7 +272,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
 
 SKGUnitPluginWidget::~SKGUnitPluginWidget()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
 }
 
 bool SKGUnitPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -309,7 +309,7 @@ void SKGUnitPluginWidget::fillSourceList()
 
 void SKGUnitPluginWidget::onSelectionChanged()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     // Mapping
     SKGUnitObject unit;
 
@@ -385,7 +385,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
 
 void SKGUnitPluginWidget::onSelectionValueChanged()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     // Mapping
     QItemSelectionModel* selModel = ui.kUnitValueTableViewEdition->selectionModel();
     if (selModel != nullptr) {
@@ -415,7 +415,7 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
 
 void SKGUnitPluginWidget::onUnitCreatorModified()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
 
     bool activated = ui.kWidgetSelector->getSelectedMode() != -1 &&
                      !ui.kNameCreatorUnit->text().isEmpty()  &&
@@ -435,19 +435,19 @@ void SKGUnitPluginWidget::onUnitCreatorModified()
 void SKGUnitPluginWidget::onAddUnit()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
     int mode = ui.kWidgetSelector->getSelectedMode();
 
     if (mode == 0) {
         QString untiname = ui.kCurrencyList->text();
-        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit creation '%1'", untiname), err);
+        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit creation '%1'", untiname), err)
         SKGUnitObject oUnit;
         err = SKGUnitObject::createCurrencyUnit(qobject_cast<SKGDocumentBank*>(getDocument()), ui.kCurrencyList->text(), oUnit);
     } else if (mode == 1) {
         QString untiname = ui.kNameCreatorUnit->text();
         SKGUnitObject unitObj(getDocument());
         {
-            SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit creation '%1'", untiname), err);
+            SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit creation '%1'", untiname), err)
 
             // Create unit object
             IFOKDO(err, unitObj.setName(untiname))
@@ -472,7 +472,7 @@ void SKGUnitPluginWidget::onAddUnit()
         QString untiname = ui.kNameCreatorUnit->text();
         SKGUnitValueObject unitValueObject;
         {
-            SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit value creation for '%1'", untiname), err);
+            SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit value creation for '%1'", untiname), err)
             IFOKDO(err, qobject_cast<SKGDocumentBank*>(getDocument())->addOrModifyUnitValue(untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject))
         }
         // status bar
@@ -492,14 +492,14 @@ void SKGUnitPluginWidget::onAddUnit()
 void SKGUnitPluginWidget::onModifyUnit()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
     // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
 
     int nb = selection.count();
 
     {
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit update"), err, nb);
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit update"), err, nb)
         auto name = ui.kNameCreatorUnit->text();
         if (name != NOUPDATE && !name.startsWith(QLatin1String("="))) {
             // Is this name already existing?
@@ -557,7 +557,7 @@ void SKGUnitPluginWidget::onModifyUnit()
             IFOKDO(err, unitObj.save())
 
             // Send message
-            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been updated", unitObj.getDisplayName()), SKGDocument::Hidden));
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been updated", unitObj.getDisplayName()), SKGDocument::Hidden))
 
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
@@ -600,13 +600,13 @@ SKGUnitObject::UnitDownloadMode SKGUnitPluginWidget::getDownloadModeFromSettings
 SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, SKGUnitObject::UnitDownloadMode iMode)
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
 
     QString unitname = iUnit.getName();
     QString code = iUnit.getInternetCode();
     auto* doc = qobject_cast<SKGDocumentBank*>(iUnit.getDocument());
     if (!code.isEmpty() && (doc != nullptr)) {
-        SKGBEGINTRANSACTION(*doc, i18nc("Noun, name of the user action", "Download values for [%1 (%2)]", unitname, code), err);
+        SKGBEGINTRANSACTION(*doc, i18nc("Noun, name of the user action", "Download values for [%1 (%2)]", unitname, code), err)
         err = const_cast<SKGUnitObject*>(&iUnit)->downloadUnitValue(iMode, skgunit_settings::nb_loaded_values());
     }
 
@@ -616,7 +616,7 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, SKGU
 void SKGUnitPluginWidget::onDownloadUnitValue()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
 
     SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
     auto* act = qobject_cast<QAction*>(sender());
@@ -629,13 +629,13 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
     int nb = selection.count();
     if (nb != 0) {
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Download values"), err, nb);
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Download values"), err, nb)
         for (int i = 0; !err && i < nb; ++i) {
             SKGUnitObject unit(selection.at(i));
             err = downloadUnitValue(unit, mode);
 
             // Send message
-            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been downloaded", unit.getDisplayName()), SKGDocument::Hidden));
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been downloaded", unit.getDisplayName()), SKGDocument::Hidden))
 
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
@@ -653,18 +653,18 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
 void SKGUnitPluginWidget::onSimplify()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
 
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
     int nb = selection.count();
     if (nb != 0) {
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Simplify unit values"), err, nb);
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Simplify unit values"), err, nb)
         for (int i = 0; !err && i < nb; ++i) {
             SKGUnitObject unit(selection.at(i));
             err = unit.simplify();
 
             // Send message
-            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been simplified", unit.getDisplayName()), SKGDocument::Hidden));
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been simplified", unit.getDisplayName()), SKGDocument::Hidden))
 
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
@@ -706,7 +706,7 @@ int SKGUnitPluginWidget::getNbSelectedObjects()
 
 QString SKGUnitPluginWidget::getState()
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     QDomDocument doc(QStringLiteral("SKGML"));
     QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
@@ -727,7 +727,7 @@ QString SKGUnitPluginWidget::getState()
 
 void SKGUnitPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEINFUNC(10);
+    SKGTRACEINFUNC(10)
     QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -768,8 +768,8 @@ QString SKGUnitPluginWidget::getDefaultStateAttribute()
 
 void SKGUnitPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEINFUNC(10);
-    Q_UNUSED(iIdTransaction);
+    SKGTRACEINFUNC(10)
+    Q_UNUSED(iIdTransaction)
 
     if (iTableName == QStringLiteral("unitvalue") || iTableName.isEmpty()) {
         // Correction bug 2299394 vvv
@@ -921,7 +921,7 @@ void SKGUnitPluginWidget::onPutNewHotStuff()
 void SKGUnitPluginWidget::onOpenURL()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err);
+    SKGTRACEINFUNCRC(10, err)
 
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
     int nb = selection.count();
