@@ -31,8 +31,6 @@ class SKGAccountObject;
  */
 class SKGBANKMODELER_EXPORT SKGBankObject final : public SKGNamedObject
 {
-    Q_OBJECT
-
 public:
     /**
      * Default constructor
@@ -70,10 +68,16 @@ public:
      */
     SKGBankObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGBankObject& operator= (const SKGBankObject& iObject);
+
     /**
      * Destructor
      */
-    ~SKGBankObject() override;
+    virtual ~SKGBankObject();
 
     /**
      * Add an account
