@@ -34,7 +34,6 @@ class SKGDocumentBank;
  */
 class SKGBANKMODELER_EXPORT SKGBudgetRuleObject final : public SKGObjectBase
 {
-    Q_OBJECT
 public:
     /**
      * Condition
@@ -75,7 +74,7 @@ public:
     /**
      * Destructor
      */
-    ~SKGBudgetRuleObject() override;
+    virtual ~SKGBudgetRuleObject();
 
     /**
      * Copy constructor
