@@ -30,7 +30,6 @@ class SKGDocumentBank;
  */
 class SKGBANKMODELER_EXPORT SKGCategoryObject final : public SKGNamedObject
 {
-    Q_OBJECT
 public:
     /**
      * Default constructor
@@ -62,10 +61,16 @@ public:
      */
     SKGCategoryObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGCategoryObject& operator= (const SKGCategoryObject& iObject);
+
     /**
      * Destructor
      */
-    ~SKGCategoryObject() override;
+    virtual ~SKGCategoryObject();
 
     /**
      * Create a category branch if needed and return the leaf of the branch
