@@ -34,7 +34,6 @@ class SKGInterestObject;
  */
 class SKGBANKMODELER_EXPORT SKGInterestObject final : public SKGObjectBase
 {
-    Q_OBJECT
 public:
     /**
      * This enumerate defines how to compute value date
@@ -94,10 +93,16 @@ public:
      */
     SKGInterestObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGInterestObject& operator= (const SKGInterestObject& iObject);
+
     /**
      * Destructor
      */
-    ~SKGInterestObject() override;
+    virtual ~SKGInterestObject();
 
     /**
      * Get the parent account
