@@ -59,6 +59,12 @@ SKGOperationObject& SKGOperationObject::operator= (const SKGObjectBase& iObject)
     return *this;
 }
 
+SKGOperationObject& SKGOperationObject::operator= (const SKGOperationObject& iObject)
+{
+    copyFrom(iObject);
+    return *this;
+}
+
 SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, QDate iDate, bool iTemplateMode) const
 {
     SKGError err;
@@ -507,7 +513,9 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     if (!err && !isBookmarked()) {
         err = bookmark(iDeletedOne.isBookmarked());
     }
-    IFOKDO(err, setNumber(iDeletedOne.getNumber()))
+    if (!err && getNumber().isEmpty()) {
+        err = setNumber(iDeletedOne.getNumber());
+    }
     IFOKDO(err, save())
 
     // Merge suboperations
