@@ -35,7 +35,6 @@ class SKGPayeeObject;
  */
 class SKGBANKMODELER_EXPORT SKGOperationObject final : public SKGObjectBase
 {
-    Q_OBJECT
 public:
     /**
      * This enumerate defines status for operations
@@ -93,10 +92,16 @@ public:
      */
     SKGOperationObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGOperationObject& operator= (const SKGOperationObject& iObject);
+
     /**
      * Destructor
      */
-    ~SKGOperationObject() override;
+    virtual ~SKGOperationObject();
 
     /**
      * Duplicate current operation including suboperations and grouped operations
