@@ -327,6 +327,7 @@ QVariantList SKGReportBank::getAccountTable()
                     double sumV1 = 0;
                     double sumV2 = 0;
                     double sumV3 = 0;
+                    int nbAdded = 0;
                     QString currentType;
                     int nb = accounts.count();
                     for (int i = 0; !err && i < nb; ++i) {
@@ -337,7 +338,7 @@ QVariantList SKGReportBank::getAccountTable()
                         QString type = account.getAttribute(QStringLiteral("t_TYPENLS"));
                         bool closed = account.isClosed();
                         if (type != currentType) {
-                            if (!currentType.isEmpty()) {
+                            if (!currentType.isEmpty() && nbAdded > 0) {
                                 table.push_back(QVariantList() << true << i18nc("Noun",  "Total of %1", currentType) << sumTypeV1 << sumTypeV2 <<
                                                 (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2
                                                 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
@@ -345,6 +346,7 @@ QVariantList SKGReportBank::getAccountTable()
                                 sumTypeV1 = 0;
                                 sumTypeV2 = 0;
                                 sumTypeV3 = 0;
+                                nbAdded = 0;
                             }
                             currentType = type;
                         }
@@ -358,6 +360,7 @@ QVariantList SKGReportBank::getAccountTable()
                             }
                             table.push_back(QVariantList() << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
                                             << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute(QStringLiteral("t_BANK")) << icon);
+                            nbAdded++;
                         }
                         sumTypeV1 += v1;
                         sumTypeV2 += v2;
