@@ -158,7 +158,7 @@ public:
     /**
      * Default Destructor
      */
-    ~SKGReportBank() override;
+    virtual ~SKGReportBank() override;
 
     /**
      * Get the budget table
