@@ -32,7 +32,6 @@
  */
 class SKGBANKMODELER_EXPORT SKGRuleObject final : public SKGObjectBase
 {
-    Q_OBJECT
 public:
     /**
      * Alarm
@@ -105,10 +104,16 @@ public:
      */
     SKGRuleObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGRuleObject& operator= (const SKGRuleObject& iObject);
+
     /**
      * Destructor
      */
-    ~SKGRuleObject() override;
+    virtual ~SKGRuleObject();
 
     /**
      * Return the name of the object for the display
