@@ -33,8 +33,6 @@ class SKGTrackerObject;
  */
 class SKGBANKMODELER_EXPORT SKGSubOperationObject final : public SKGObjectBase
 {
-    Q_OBJECT
-
 public:
     /**
      * Default constructor
@@ -66,10 +64,16 @@ public:
      */
     SKGSubOperationObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGSubOperationObject& operator= (const SKGSubOperationObject& iObject);
+
     /**
      * Destructor
      */
-    ~SKGSubOperationObject() override;
+    virtual ~SKGSubOperationObject();
 
     /**
      * Set date of this suboperation
