@@ -36,7 +36,6 @@ class SKGDocumentBank;
  */
 class SKGBANKMODELER_EXPORT SKGUnitObject final : public SKGNamedObject
 {
-    Q_OBJECT
 public:
     /**
      * This enumerate defines type of units
@@ -84,7 +83,7 @@ public:
     /**
      * Destructor
      */
-    ~SKGUnitObject() override;
+    virtual ~SKGUnitObject();
 
     /**
      * Copy constructor
@@ -104,13 +103,18 @@ public:
      */
     explicit SKGUnitObject(const SKGObjectBase& iObject);
 
-
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
     SKGUnitObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGUnitObject& operator= (const SKGUnitObject& iObject);
+
     /**
      * Get unit information
      * @return the unit information
