@@ -33,8 +33,6 @@ class SKGUnitObject;
  */
 class SKGBANKMODELER_EXPORT SKGUnitValueObject final : public SKGObjectBase
 {
-    Q_OBJECT
-
 public:
     /**
      * Default constructor
@@ -66,10 +64,16 @@ public:
      */
     SKGUnitValueObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGUnitValueObject& operator= (const SKGUnitValueObject& iObject);
+
     /**
      * Destructor
      */
-    ~SKGUnitValueObject() override;
+    virtual ~SKGUnitValueObject();
 
     /**
      * Set the quantity for the date of this unit
