@@ -1117,8 +1117,8 @@ bool SKGTreeView::eventFilter(QObject* iObject, QEvent* iEvent)
 {
     if (iObject == this && iEvent != nullptr && iEvent->type() == QEvent::Wheel) {
         auto* e = dynamic_cast<QWheelEvent*>(iEvent);
-        if (m_textResizable && (e != nullptr) && e->orientation() == Qt::Vertical && ((QApplication::keyboardModifiers() &Qt::ControlModifier) != 0u)) {
-            int numDegrees = e->delta() / 8;
+        if (m_textResizable && (e != nullptr) && ((QApplication::keyboardModifiers() &Qt::ControlModifier) != 0u)) {
+            int numDegrees = e->angleDelta().y() / 8;
             int numTicks = numDegrees / 15;
 
             setZoomPosition(zoomPosition() + (numTicks > 0 ? 1 : -1));
