@@ -21,7 +21,7 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include <customwidget.h>
+#include <QtUiPlugin/customwidget.h>
 
 /**
  * QDesigner plugin for SKGProgressBar
