@@ -22,18 +22,18 @@
 #include "skgerror.h"
 
 SKGError::SKGError()
-    : QObject(), m_message(QLatin1String(""))
+    : m_message(QLatin1String("")), m_property(QLatin1String(""))
 {}
 
 SKGError::SKGError(int iRc, QString  iMessage, QString  iAction)
-    : QObject(), m_rc(iRc), m_message(std::move(iMessage)), m_action(std::move(iAction)), m_previousError(nullptr)
+    : m_rc(iRc), m_message(std::move(iMessage)),  m_property(QLatin1String("")), m_action(std::move(iAction)), m_previousError(nullptr)
 {}
 
 SKGError::SKGError(const SKGError& iError)
-    : QObject()
 {
     m_rc = iError.m_rc;
     m_message = iError.m_message;
+    m_property = iError.m_property;
     m_action = iError.m_action;
     if (Q_UNLIKELY(iError.m_previousError != nullptr)) {
         m_previousError = new SKGError(*iError.m_previousError);
@@ -43,10 +43,10 @@ SKGError::SKGError(const SKGError& iError)
 }
 
 SKGError::SKGError(SKGError&& iError) noexcept
-    : QObject()
 {
     m_rc = iError.m_rc;
     m_message = iError.m_message;
+    m_property = iError.m_property;
     m_action = iError.m_action;
     m_previousError = iError.m_previousError;
     iError.m_previousError = nullptr;
@@ -66,12 +66,12 @@ SKGError& SKGError::operator= (const SKGError& iError)
 
         m_rc = iError.m_rc;
         m_message = iError.m_message;
+        m_property = iError.m_property;
         m_action = iError.m_action;
         if (Q_UNLIKELY(iError.m_previousError != nullptr)) {
             m_previousError = new SKGError(*iError.m_previousError);
         }
     }
-    Q_EMIT modified();
     return *this;
 }
 
@@ -107,19 +107,13 @@ int SKGError::getReturnCode() const
 
 SKGError& SKGError::setReturnCode(int iReturnCode)
 {
-    if (m_rc != iReturnCode) {
-        m_rc = iReturnCode;
-        Q_EMIT modified();
-    }
+    m_rc = iReturnCode;
     return *this;
 }
 
 SKGError& SKGError::setMessage(const QString& iMessage)
 {
-    if (m_message != iMessage) {
-        m_message = iMessage;
-        Q_EMIT modified();
-    }
+    m_message = iMessage;
     return *this;
 }
 
@@ -128,6 +122,17 @@ QString SKGError::getMessage() const
     return m_message;
 }
 
+SKGError& SKGError::setProperty(const QString& iProperty)
+{
+    m_property = iProperty;
+    return *this;
+}
+
+QString SKGError::getProperty() const
+{
+    return m_property;
+}
+
 QString SKGError::getFullMessage() const
 {
     QString output('[');
@@ -167,7 +172,6 @@ SKGError& SKGError::setAction(const QString& iAction)
 {
     if (m_action != iAction) {
         m_action = iAction;
-        Q_EMIT modified();
     }
     return *this;
 }
@@ -185,7 +189,6 @@ SKGError& SKGError::addError(int iRc, const QString& iMessage, const QString& iA
     setAction(iAction);
     delete m_previousError;
     m_previousError = pe;
-    Q_EMIT modified();
     return *this;
 }
 
