@@ -48,29 +48,32 @@
 /**
 * This class manages errors
 */
-class SKGBASEMODELER_EXPORT SKGError final : public QObject
+class SKGBASEMODELER_EXPORT SKGError final
 {
-    Q_OBJECT
     /**
      * Return code of the error
      */
-    Q_PROPERTY(int returnCode READ getReturnCode WRITE setReturnCode NOTIFY modified)
+    Q_PROPERTY(int returnCode READ getReturnCode WRITE setReturnCode)
     /**
      * Message of the error
      */
-    Q_PROPERTY(QString message READ getMessage WRITE setMessage NOTIFY modified)
+    Q_PROPERTY(QString message READ getMessage WRITE setMessage)
+    /**
+     * Internal data of the error
+     */
+    Q_PROPERTY(QString property READ getProperty WRITE setProperty)
     /**
      * Action of the error
      */
-    Q_PROPERTY(QString action READ getAction WRITE setAction NOTIFY modified)
+    Q_PROPERTY(QString action READ getAction WRITE setAction)
     /**
      * To know if it is a success of the error
      */
-    Q_PROPERTY(bool succeeded READ isSucceeded NOTIFY modified)
+    Q_PROPERTY(bool succeeded READ isSucceeded)
     /**
      * To know if it is a failure of the error
      */
-    Q_PROPERTY(bool failed READ isFailed NOTIFY modified)
+    Q_PROPERTY(bool failed READ isFailed)
 public:
     /**
     * Constructor
@@ -100,7 +103,7 @@ public:
     /**
     * Destructor
     */
-    ~SKGError() override;
+    ~SKGError();
 
     /**
     * Operator affectation
@@ -155,6 +158,12 @@ public:
     */
     QString getMessage() const;
 
+    /**
+    * Return the internal data associated to this error
+    * @return the internal data
+    */
+    QString getProperty() const;
+
     /**
     * Return the full message associated to this error
     * @return the full message
@@ -202,7 +211,14 @@ public Q_SLOTS:
     * @param iMessage the message
     * @return itself to facilitate usage
     */
-    SKGError& setMessage(const QString&   iMessage);
+    SKGError& setMessage(const QString& iMessage);
+
+    /**
+    * Set internal data associated to this error
+    * @param iProperty the internal data
+    * @return itself to facilitate usage
+    */
+    SKGError& setProperty(const QString& iProperty);
 
     /**
     * Set the action associated to this error
@@ -227,13 +243,8 @@ public Q_SLOTS:
     */
     SKGError& addError(const SKGError& iError);
 
-Q_SIGNALS:
-    /**
-     * This signal is launched when the error is modified
-     */
-    void modified();
-
 private:
+    Q_GADGET
     /**
     * the return code of the error
     *         0 : It is not an error (SUCCEEDED)
@@ -247,6 +258,11 @@ private:
      */
     QString m_message;
 
+    /**
+     * the property of the error
+     */
+    QString m_property;
+
     /**
      * the action of the error
      */
