@@ -85,7 +85,7 @@ SKGObjectBase::~SKGObjectBase()
 }
 
 SKGObjectBase::SKGObjectBase(const SKGObjectBase& iObject)
-    : QObject(), d(new SKGObjectBasePrivate)
+    : d(new SKGObjectBasePrivate)
 {
     copyFrom(iObject);
 }
@@ -170,7 +170,6 @@ void SKGObjectBase::copyFrom(const SKGObjectBase& iObject)
     d->table = iObject.d->table;
     d->document = iObject.d->document;
     d->attributes = iObject.d->attributes;
-    Q_EMIT modified();
 }
 
 SKGObjectBase SKGObjectBase::cloneInto()
@@ -189,14 +188,12 @@ SKGObjectBase SKGObjectBase::cloneInto(SKGDocument* iDocument)
     output.copyFrom(*this);
     output.d->id = 0;
     output.d->document = targetDocument;
-    Q_EMIT modified();
     return output;
 }
 
 SKGError SKGObjectBase::resetID()
 {
     d->id = 0;
-    Q_EMIT modified();
     return SKGError();
 }
 
@@ -285,7 +282,6 @@ SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue
         }
         d->attributes[iName] = val;
     }
-    Q_EMIT modified();
     return err;
 }
 
@@ -399,7 +395,6 @@ SKGError SKGObjectBase::load()
             }
         }
     }
-    Q_EMIT modified();
     return err;
 }
 
