@@ -40,9 +40,8 @@ class SKGObjectBasePrivate;
  * R1: Each table must have a view named v_[tablename] where [tablename] is the name of the table.
  * R2: Each computed attribute of the view must have a name starting with v_
  */
-class SKGBASEMODELER_EXPORT SKGObjectBase : public QObject
+class SKGBASEMODELER_EXPORT SKGObjectBase
 {
-    Q_OBJECT
     /**
      * Unique ide  of the object
      */
@@ -136,7 +135,7 @@ public:
     /**
      * Destructor
      */
-    ~SKGObjectBase() override;
+    virtual ~SKGObjectBase();
 
     /**
      * Return the unique id of this object
@@ -341,13 +340,8 @@ protected:
      */
     virtual QString getWhereclauseId() const;
 
-Q_SIGNALS:
-    /**
-     * This signal is launched when the object is modified
-     */
-    void modified();
-
 private:
+    Q_GADGET
     SKGObjectBasePrivate* d;
 };
 /**
