@@ -31,7 +31,6 @@ class SKGDocument;
  */
 class SKGBASEMODELER_EXPORT SKGPropertyObject final : public SKGNamedObject
 {
-    Q_OBJECT
     /**
      * Value of the property
      */
@@ -71,10 +70,16 @@ public:
      */
     SKGPropertyObject& operator= (const SKGObjectBase& iObject);
 
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    SKGPropertyObject& operator= (const SKGPropertyObject& iObject);
+
     /**
      * Destructor
      */
-    ~SKGPropertyObject() override;
+    virtual ~SKGPropertyObject();
 
     /**
      * Set the value of the property
