@@ -518,8 +518,7 @@ QDate SKGServices::partialStringToDate(const QString& iDateString, bool iFixupBa
     if (size == 1) {
         int dayCount = items.at(0).toInt(&ok);
 
-        result = QDate::currentDate();
-        result = result.addDays(dayCount - result.day());
+        result = QDate(QDate::currentDate().year(), QDate::currentDate().month(), dayCount);
 
         if (iFixupBackward) {
             if (result > QDate::currentDate()) {
@@ -534,9 +533,7 @@ QDate SKGServices::partialStringToDate(const QString& iDateString, bool iFixupBa
         int dayCount = items.at(0).toInt(&ok);
         int monthCount = items.at(1).toInt(&ok);
 
-        result = QDate::currentDate();
-        result = result.addDays(dayCount - result.day());
-        result = result.addMonths(monthCount - result.month());
+        result = QDate(QDate::currentDate().year(), monthCount, dayCount);
 
         if (iFixupBackward) {
             if (result > QDate::currentDate()) {
@@ -553,9 +550,7 @@ QDate SKGServices::partialStringToDate(const QString& iDateString, bool iFixupBa
         int yearCount = items.at(2).toInt(&ok);
         int lengthYear = items.at(2).count();
 
-        result = QDate::currentDate();
-        result = result.addDays(dayCount - result.day());
-        result = result.addMonths(monthCount - result.month());
+        result = QDate(QDate::currentDate().year(), monthCount, dayCount);
 
         if (lengthYear < 4) {
             auto y = static_cast<int>(result.year() / qPow(10, lengthYear)) * qPow(10, lengthYear) + yearCount;
@@ -1990,6 +1985,8 @@ QIcon SKGServices::fromTheme(const QString& iName, const QStringList& iOverlays)
             alternatives[QStringLiteral("edit_undo")] = QStringLiteral("edit-undo");
             alternatives[QStringLiteral("nextuntranslated")] = QStringLiteral("debug-execute-to-cursor");
             alternatives[QStringLiteral("format-precision-less")] = QStringLiteral("visibility");
+            alternatives[QStringLiteral("format-indent-more")] = QStringLiteral("go-next");
+            alternatives[QStringLiteral("format-indent-less")] = QStringLiteral("go-previous");
         }
         bool alternativeEmpty = false;
         if (alternatives.contains(iName)) {
