@@ -136,8 +136,6 @@ int main(int argc, char** argv)
     QApplication::setApplicationVersion(about.version());
 
     QCommandLineParser parser;
-    parser.addVersionOption();
-    parser.addHelpOption();
     parser.addPositionalArgument(QStringLiteral("URL"), i18nc("Application argument", "Document to open"));
     QCommandLineOption envOption(QStringList() << QStringLiteral("e") << QStringLiteral("env"), i18nc("Application argument", "Display environment variables used by this application."));
     parser.addOption(envOption);
