@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
+ *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
  * This file is a test script.
@@ -30,73 +30,73 @@
  */
 int main(int argc, char** argv)
 {
-    Q_UNUSED(argc);
-    Q_UNUSED(argv);
+    Q_UNUSED(argc)
+    Q_UNUSED(argv)
 
     // Init test
-    SKGINITTEST(true);
+    SKGINITTEST(true)
 
     {
         // Test import GSK
         SKGDocumentBank document1;
-        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
         SKGError err;
         {
             // Scope of the transaction
-            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_MMB"), err);
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_MMB"), err)
             SKGImportExportManager impmissing(&document1, QUrl::fromLocalFile(QStringLiteral("missingfile.mmb")));
-            SKGTESTERROR(QStringLiteral("imp1.importFile"), impmissing.importFile(), false);
+            SKGTESTERROR(QStringLiteral("imp1.importFile"), impmissing.importFile(), false)
 
             SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmmb/test.mmb"));
-            SKGTESTERROR(QStringLiteral("MMB.importFile"), imp1.importFile(), true);
+            SKGTESTERROR(QStringLiteral("MMB.importFile"), imp1.importFile(), true)
         }
 
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("COURANT")), true);
-            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true);
-            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("-144.05"));
+            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("COURANT")), true)
+            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true)
+            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("-144.05"))
         }
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("CPT2")), true);
-            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true);
-            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("40"));
+            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("CPT2")), true)
+            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true)
+            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("40"))
         }
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("NOTFAVORITE")), true);
-            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true);
-            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("150"));
+            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("NOTFAVORITE")), true)
+            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true)
+            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("150"))
         }
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("LEP")), true);
-            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true);
-            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("6000"));
+            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("LEP")), true)
+            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true)
+            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("6000"))
         }
     }
 
     {
         // Test import GSK
         SKGDocumentBank document1;
-        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
         SKGError err;
         {
             // Scope of the transaction
-            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_MMB"), err);
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_MMB"), err)
 
             SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmmb/jd.mmb"));
-            SKGTESTERROR(QStringLiteral("MMB.importFile"), imp1.importFile(), true);
+            SKGTESTERROR(QStringLiteral("MMB.importFile"), imp1.importFile(), true)
         }
 
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("credit")), true);
-            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true);
-            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("-974.04"));
+            SKGTESTERROR(QStringLiteral("MMB.setName"), account.setName(QStringLiteral("credit")), true)
+            SKGTESTERROR(QStringLiteral("MMB.load"), account.load(), true)
+            SKGTEST(QStringLiteral("GSB:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("-974.04"))
         }
     }
     // End test
-    SKGENDTEST();
+    SKGENDTEST()
 }
