@@ -70,7 +70,7 @@ int main(int argc, char** argv)
     QVector<test> listTests;
     {
         test t1;
-        t1.fileName = QStringLiteral("sunset-sample-5-pwd:12@a!.mny");
+        t1.fileName = QStringLiteral("sunset-sample-5-pwd-12@a!.mny");
         t1.password = QStringLiteral("12@a!");
 
         QMap<QString, double> accounts;
