@@ -370,23 +370,7 @@ int main(int argc, char** argv)
 
             SKGObjectBase::SKGListSKGObjectBase values;
             SKGTESTERROR(QStringLiteral("UNIT:getUnitValues"), unit1.getUnitValues(values), true)
-            SKGTESTBOOL("UNIT:getUnitValues", (!values.isEmpty()), true)
-        }
-    }
-    {
-        // Unit download
-        SKGDocumentBank document1;
-        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
-        SKGError err;
-        SKGUnitObject unit1(&document1);
-        {
-            SKGBEGINTRANSACTION(document1, QStringLiteral("UNIT"), err)
-            SKGTESTERROR(QStringLiteral("UNIT:createCurrencyUnit"), SKGUnitObject::createCurrencyUnit(&document1, QStringLiteral("Bitcoin"), unit1), true)
-            SKGTESTERROR(QStringLiteral("UNIT:downloadUnitValue"), unit1.downloadUnitValue(SKGUnitObject::LAST), true)
-
-            SKGObjectBase::SKGListSKGObjectBase values;
-            SKGTESTERROR(QStringLiteral("UNIT:getUnitValues"), unit1.getUnitValues(values), true)
-            SKGTESTBOOL("UNIT:getUnitValues", (!values.isEmpty()), true)
+            SKGTESTBOOL("UNIT:getUnitValues.isEmpty", values.isEmpty(), false)
         }
     }
     {
